# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include controltower_service.R
NULL

#' Creates a new landing zone
#'
#' @description
#' Creates a new landing zone. This API call starts an asynchronous operation that creates and configures a landing zone, based on the parameters specified in the manifest JSON file.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_create_landing_zone/](https://www.paws-r-sdk.com/docs/controltower_create_landing_zone/) for full documentation.
#'
#' @param manifest &#91;required&#93; The manifest JSON file is a text file that describes your Amazon Web
#' Services resources. For examples, review [Launch your landing
#' zone](https://docs.aws.amazon.com/controltower/latest/userguide/lz-api-launch.html).
#' @param tags Tags to be applied to the landing zone.
#' @param version &#91;required&#93; The landing zone version, for example, 3.0.
#'
#' @keywords internal
#'
#' @rdname controltower_create_landing_zone
controltower_create_landing_zone <- function(manifest, tags = NULL, version) {
  op <- new_operation(
    name = "CreateLandingZone",
    http_method = "POST",
    http_path = "/create-landingzone",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$create_landing_zone_input(manifest = manifest, tags = tags, version = version)
  output <- .controltower$create_landing_zone_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$create_landing_zone <- controltower_create_landing_zone

#' Decommissions a landing zone
#'
#' @description
#' Decommissions a landing zone. This API call starts an asynchronous operation that deletes Amazon Web Services Control Tower resources deployed in accounts managed by Amazon Web Services Control Tower.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_delete_landing_zone/](https://www.paws-r-sdk.com/docs/controltower_delete_landing_zone/) for full documentation.
#'
#' @param landingZoneIdentifier &#91;required&#93; The unique identifier of the landing zone.
#'
#' @keywords internal
#'
#' @rdname controltower_delete_landing_zone
controltower_delete_landing_zone <- function(landingZoneIdentifier) {
  op <- new_operation(
    name = "DeleteLandingZone",
    http_method = "POST",
    http_path = "/delete-landingzone",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$delete_landing_zone_input(landingZoneIdentifier = landingZoneIdentifier)
  output <- .controltower$delete_landing_zone_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$delete_landing_zone <- controltower_delete_landing_zone

#' Disable an EnabledBaseline resource on the specified Target
#'
#' @description
#' Disable an `EnabledBaseline` resource on the specified Target. This API starts an asynchronous operation to remove all resources deployed as part of the baseline enablement. The resource will vary depending on the enabled baseline. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_disable_baseline/](https://www.paws-r-sdk.com/docs/controltower_disable_baseline/) for full documentation.
#'
#' @param enabledBaselineIdentifier &#91;required&#93; Identifier of the `EnabledBaseline` resource to be deactivated, in ARN
#' format.
#'
#' @keywords internal
#'
#' @rdname controltower_disable_baseline
controltower_disable_baseline <- function(enabledBaselineIdentifier) {
  op <- new_operation(
    name = "DisableBaseline",
    http_method = "POST",
    http_path = "/disable-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$disable_baseline_input(enabledBaselineIdentifier = enabledBaselineIdentifier)
  output <- .controltower$disable_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$disable_baseline <- controltower_disable_baseline

#' This API call turns off a control
#'
#' @description
#' This API call turns off a control. It starts an asynchronous operation that deletes Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources will vary according to the control that you specify. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_disable_control/](https://www.paws-r-sdk.com/docs/controltower_disable_control/) for full documentation.
#'
#' @param controlIdentifier &#91;required&#93; The ARN of the control. Only **Strongly recommended** and **Elective**
#' controls are permitted, with the exception of the **Region deny**
#' control. For information on how to find the `controlIdentifier`, see
#' [the overview
#' page](https://docs.aws.amazon.com/controltower/latest/APIReference/Welcome.html).
#' @param targetIdentifier &#91;required&#93; The ARN of the organizational unit. For information on how to find the
#' `targetIdentifier`, see [the overview
#' page](https://docs.aws.amazon.com/controltower/latest/APIReference/Welcome.html).
#'
#' @keywords internal
#'
#' @rdname controltower_disable_control
controltower_disable_control <- function(controlIdentifier, targetIdentifier) {
  op <- new_operation(
    name = "DisableControl",
    http_method = "POST",
    http_path = "/disable-control",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$disable_control_input(controlIdentifier = controlIdentifier, targetIdentifier = targetIdentifier)
  output <- .controltower$disable_control_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$disable_control <- controltower_disable_control

#' Enable (apply) a Baseline to a Target
#'
#' @description
#' Enable (apply) a `Baseline` to a Target. This API starts an asynchronous operation to deploy resources specified by the `Baseline` to the specified Target. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_enable_baseline/](https://www.paws-r-sdk.com/docs/controltower_enable_baseline/) for full documentation.
#'
#' @param baselineIdentifier &#91;required&#93; The ARN of the baseline to be enabled.
#' @param baselineVersion &#91;required&#93; The specific version to be enabled of the specified baseline.
#' @param parameters A list of `key-value` objects that specify enablement parameters, where
#' `key` is a string and `value` is a document of any type.
#' @param tags Tags associated with input to
#' [`enable_baseline`][controltower_enable_baseline].
#' @param targetIdentifier &#91;required&#93; The ARN of the target on which the baseline will be enabled. Only OUs
#' are supported as targets.
#'
#' @keywords internal
#'
#' @rdname controltower_enable_baseline
controltower_enable_baseline <- function(baselineIdentifier, baselineVersion, parameters = NULL, tags = NULL, targetIdentifier) {
  op <- new_operation(
    name = "EnableBaseline",
    http_method = "POST",
    http_path = "/enable-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$enable_baseline_input(baselineIdentifier = baselineIdentifier, baselineVersion = baselineVersion, parameters = parameters, tags = tags, targetIdentifier = targetIdentifier)
  output <- .controltower$enable_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$enable_baseline <- controltower_enable_baseline

#' This API call activates a control
#'
#' @description
#' This API call activates a control. It starts an asynchronous operation that creates Amazon Web Services resources on the specified organizational unit and the accounts it contains. The resources created will vary according to the control that you specify. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_enable_control/](https://www.paws-r-sdk.com/docs/controltower_enable_control/) for full documentation.
#'
#' @param controlIdentifier &#91;required&#93; The ARN of the control. Only **Strongly recommended** and **Elective**
#' controls are permitted, with the exception of the **Region deny**
#' control. For information on how to find the `controlIdentifier`, see
#' [the overview
#' page](https://docs.aws.amazon.com/controltower/latest/APIReference/Welcome.html).
#' @param parameters A list of input parameter values, which are specified to configure the
#' control when you enable it.
#' @param tags Tags to be applied to the `EnabledControl` resource.
#' @param targetIdentifier &#91;required&#93; The ARN of the organizational unit. For information on how to find the
#' `targetIdentifier`, see [the overview
#' page](https://docs.aws.amazon.com/controltower/latest/APIReference/Welcome.html).
#'
#' @keywords internal
#'
#' @rdname controltower_enable_control
controltower_enable_control <- function(controlIdentifier, parameters = NULL, tags = NULL, targetIdentifier) {
  op <- new_operation(
    name = "EnableControl",
    http_method = "POST",
    http_path = "/enable-control",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$enable_control_input(controlIdentifier = controlIdentifier, parameters = parameters, tags = tags, targetIdentifier = targetIdentifier)
  output <- .controltower$enable_control_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$enable_control <- controltower_enable_control

#' Retrieve details about an existing Baseline resource by specifying its
#' identifier
#'
#' @description
#' Retrieve details about an existing `Baseline` resource by specifying its identifier. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_baseline/](https://www.paws-r-sdk.com/docs/controltower_get_baseline/) for full documentation.
#'
#' @param baselineIdentifier &#91;required&#93; The ARN of the `Baseline` resource to be retrieved.
#'
#' @keywords internal
#'
#' @rdname controltower_get_baseline
controltower_get_baseline <- function(baselineIdentifier) {
  op <- new_operation(
    name = "GetBaseline",
    http_method = "POST",
    http_path = "/get-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_baseline_input(baselineIdentifier = baselineIdentifier)
  output <- .controltower$get_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_baseline <- controltower_get_baseline

#' Returns the details of an asynchronous baseline operation, as initiated
#' by any of these APIs: EnableBaseline, DisableBaseline,
#' UpdateEnabledBaseline, ResetEnabledBaseline
#'
#' @description
#' Returns the details of an asynchronous baseline operation, as initiated by any of these APIs: [`enable_baseline`][controltower_enable_baseline], [`disable_baseline`][controltower_disable_baseline], [`update_enabled_baseline`][controltower_update_enabled_baseline], [`reset_enabled_baseline`][controltower_reset_enabled_baseline]. A status message is displayed in case of operation failure. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_baseline_operation/](https://www.paws-r-sdk.com/docs/controltower_get_baseline_operation/) for full documentation.
#'
#' @param operationIdentifier &#91;required&#93; The operation ID returned from mutating asynchronous APIs (Enable,
#' Disable, Update, Reset).
#'
#' @keywords internal
#'
#' @rdname controltower_get_baseline_operation
controltower_get_baseline_operation <- function(operationIdentifier) {
  op <- new_operation(
    name = "GetBaselineOperation",
    http_method = "POST",
    http_path = "/get-baseline-operation",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_baseline_operation_input(operationIdentifier = operationIdentifier)
  output <- .controltower$get_baseline_operation_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_baseline_operation <- controltower_get_baseline_operation

#' Returns the status of a particular EnableControl or DisableControl
#' operation
#'
#' @description
#' Returns the status of a particular [`enable_control`][controltower_enable_control] or [`disable_control`][controltower_disable_control] operation. Displays a message in case of error. Details for an operation are available for 90 days. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_control_operation/](https://www.paws-r-sdk.com/docs/controltower_get_control_operation/) for full documentation.
#'
#' @param operationIdentifier &#91;required&#93; The ID of the asynchronous operation, which is used to track status. The
#' operation is available for 90 days.
#'
#' @keywords internal
#'
#' @rdname controltower_get_control_operation
controltower_get_control_operation <- function(operationIdentifier) {
  op <- new_operation(
    name = "GetControlOperation",
    http_method = "POST",
    http_path = "/get-control-operation",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_control_operation_input(operationIdentifier = operationIdentifier)
  output <- .controltower$get_control_operation_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_control_operation <- controltower_get_control_operation

#' Retrieve details of an EnabledBaseline resource by specifying its
#' identifier
#'
#' @description
#' Retrieve details of an `EnabledBaseline` resource by specifying its identifier.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_enabled_baseline/](https://www.paws-r-sdk.com/docs/controltower_get_enabled_baseline/) for full documentation.
#'
#' @param enabledBaselineIdentifier &#91;required&#93; Identifier of the `EnabledBaseline` resource to be retrieved, in ARN
#' format.
#'
#' @keywords internal
#'
#' @rdname controltower_get_enabled_baseline
controltower_get_enabled_baseline <- function(enabledBaselineIdentifier) {
  op <- new_operation(
    name = "GetEnabledBaseline",
    http_method = "POST",
    http_path = "/get-enabled-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_enabled_baseline_input(enabledBaselineIdentifier = enabledBaselineIdentifier)
  output <- .controltower$get_enabled_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_enabled_baseline <- controltower_get_enabled_baseline

#' Retrieves details about an enabled control
#'
#' @description
#' Retrieves details about an enabled control. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_enabled_control/](https://www.paws-r-sdk.com/docs/controltower_get_enabled_control/) for full documentation.
#'
#' @param enabledControlIdentifier &#91;required&#93; The `controlIdentifier` of the enabled control.
#'
#' @keywords internal
#'
#' @rdname controltower_get_enabled_control
controltower_get_enabled_control <- function(enabledControlIdentifier) {
  op <- new_operation(
    name = "GetEnabledControl",
    http_method = "POST",
    http_path = "/get-enabled-control",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_enabled_control_input(enabledControlIdentifier = enabledControlIdentifier)
  output <- .controltower$get_enabled_control_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_enabled_control <- controltower_get_enabled_control

#' Returns details about the landing zone
#'
#' @description
#' Returns details about the landing zone. Displays a message in case of error.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_landing_zone/](https://www.paws-r-sdk.com/docs/controltower_get_landing_zone/) for full documentation.
#'
#' @param landingZoneIdentifier &#91;required&#93; The unique identifier of the landing zone.
#'
#' @keywords internal
#'
#' @rdname controltower_get_landing_zone
controltower_get_landing_zone <- function(landingZoneIdentifier) {
  op <- new_operation(
    name = "GetLandingZone",
    http_method = "POST",
    http_path = "/get-landingzone",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_landing_zone_input(landingZoneIdentifier = landingZoneIdentifier)
  output <- .controltower$get_landing_zone_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_landing_zone <- controltower_get_landing_zone

#' Returns the status of the specified landing zone operation
#'
#' @description
#' Returns the status of the specified landing zone operation. Details for an operation are available for 90 days.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_get_landing_zone_operation/](https://www.paws-r-sdk.com/docs/controltower_get_landing_zone_operation/) for full documentation.
#'
#' @param operationIdentifier &#91;required&#93; A unique identifier assigned to a landing zone operation.
#'
#' @keywords internal
#'
#' @rdname controltower_get_landing_zone_operation
controltower_get_landing_zone_operation <- function(operationIdentifier) {
  op <- new_operation(
    name = "GetLandingZoneOperation",
    http_method = "POST",
    http_path = "/get-landingzone-operation",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$get_landing_zone_operation_input(operationIdentifier = operationIdentifier)
  output <- .controltower$get_landing_zone_operation_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$get_landing_zone_operation <- controltower_get_landing_zone_operation

#' Returns a summary list of all available baselines
#'
#' @description
#' Returns a summary list of all available baselines. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_baselines/](https://www.paws-r-sdk.com/docs/controltower_list_baselines/) for full documentation.
#'
#' @param maxResults The maximum number of results to be shown.
#' @param nextToken A pagination token.
#'
#' @keywords internal
#'
#' @rdname controltower_list_baselines
controltower_list_baselines <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListBaselines",
    http_method = "POST",
    http_path = "/list-baselines",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "baselines"),
    stream_api = FALSE
  )
  input <- .controltower$list_baselines_input(maxResults = maxResults, nextToken = nextToken)
  output <- .controltower$list_baselines_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_baselines <- controltower_list_baselines

#' Provides a list of operations in progress or queued
#'
#' @description
#' Provides a list of operations in progress or queued. For usage examples, see [ListControlOperation examples](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html#list-control-operations-api-examples).
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_control_operations/](https://www.paws-r-sdk.com/docs/controltower_list_control_operations/) for full documentation.
#'
#' @param filter An input filter for the
#' [`list_control_operations`][controltower_list_control_operations] API
#' that lets you select the types of control operations to view.
#' @param maxResults The maximum number of results to be shown.
#' @param nextToken A pagination token.
#'
#' @keywords internal
#'
#' @rdname controltower_list_control_operations
controltower_list_control_operations <- function(filter = NULL, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListControlOperations",
    http_method = "POST",
    http_path = "/list-control-operations",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "controlOperations"),
    stream_api = FALSE
  )
  input <- .controltower$list_control_operations_input(filter = filter, maxResults = maxResults, nextToken = nextToken)
  output <- .controltower$list_control_operations_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_control_operations <- controltower_list_control_operations

#' Returns a list of summaries describing EnabledBaseline resources
#'
#' @description
#' Returns a list of summaries describing `EnabledBaseline` resources. You can filter the list by the corresponding `Baseline` or `Target` of the `EnabledBaseline` resources. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_enabled_baselines/](https://www.paws-r-sdk.com/docs/controltower_list_enabled_baselines/) for full documentation.
#'
#' @param filter A filter applied on the `ListEnabledBaseline` operation. Allowed filters
#' are `baselineIdentifiers` and `targetIdentifiers`. The filter can be
#' applied for either, or both.
#' @param includeChildren A value that can be set to include the child enabled baselines in
#' responses. The default value is false.
#' @param maxResults The maximum number of results to be shown.
#' @param nextToken A pagination token.
#'
#' @keywords internal
#'
#' @rdname controltower_list_enabled_baselines
controltower_list_enabled_baselines <- function(filter = NULL, includeChildren = NULL, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListEnabledBaselines",
    http_method = "POST",
    http_path = "/list-enabled-baselines",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "enabledBaselines"),
    stream_api = FALSE
  )
  input <- .controltower$list_enabled_baselines_input(filter = filter, includeChildren = includeChildren, maxResults = maxResults, nextToken = nextToken)
  output <- .controltower$list_enabled_baselines_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_enabled_baselines <- controltower_list_enabled_baselines

#' Lists the controls enabled by Amazon Web Services Control Tower on the
#' specified organizational unit and the accounts it contains
#'
#' @description
#' Lists the controls enabled by Amazon Web Services Control Tower on the specified organizational unit and the accounts it contains. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_enabled_controls/](https://www.paws-r-sdk.com/docs/controltower_list_enabled_controls/) for full documentation.
#'
#' @param filter An input filter for the
#' [`list_enabled_controls`][controltower_list_enabled_controls] API that
#' lets you select the types of control operations to view.
#' @param maxResults How many results to return per API call.
#' @param nextToken The token to continue the list from a previous API call with the same
#' parameters.
#' @param targetIdentifier The ARN of the organizational unit. For information on how to find the
#' `targetIdentifier`, see [the overview
#' page](https://docs.aws.amazon.com/controltower/latest/APIReference/Welcome.html).
#'
#' @keywords internal
#'
#' @rdname controltower_list_enabled_controls
controltower_list_enabled_controls <- function(filter = NULL, maxResults = NULL, nextToken = NULL, targetIdentifier = NULL) {
  op <- new_operation(
    name = "ListEnabledControls",
    http_method = "POST",
    http_path = "/list-enabled-controls",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "enabledControls"),
    stream_api = FALSE
  )
  input <- .controltower$list_enabled_controls_input(filter = filter, maxResults = maxResults, nextToken = nextToken, targetIdentifier = targetIdentifier)
  output <- .controltower$list_enabled_controls_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_enabled_controls <- controltower_list_enabled_controls

#' Lists all landing zone operations from the past 90 days
#'
#' @description
#' Lists all landing zone operations from the past 90 days. Results are sorted by time, with the most recent operation first.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_landing_zone_operations/](https://www.paws-r-sdk.com/docs/controltower_list_landing_zone_operations/) for full documentation.
#'
#' @param filter An input filter for the
#' [`list_landing_zone_operations`][controltower_list_landing_zone_operations]
#' API that lets you select the types of landing zone operations to view.
#' @param maxResults How many results to return per API call.
#' @param nextToken The token to continue the list from a previous API call with the same
#' parameters.
#'
#' @keywords internal
#'
#' @rdname controltower_list_landing_zone_operations
controltower_list_landing_zone_operations <- function(filter = NULL, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListLandingZoneOperations",
    http_method = "POST",
    http_path = "/list-landingzone-operations",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "landingZoneOperations"),
    stream_api = FALSE
  )
  input <- .controltower$list_landing_zone_operations_input(filter = filter, maxResults = maxResults, nextToken = nextToken)
  output <- .controltower$list_landing_zone_operations_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_landing_zone_operations <- controltower_list_landing_zone_operations

#' Returns the landing zone ARN for the landing zone deployed in your
#' managed account
#'
#' @description
#' Returns the landing zone ARN for the landing zone deployed in your managed account. This API also creates an ARN for existing accounts that do not yet have a landing zone ARN.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_landing_zones/](https://www.paws-r-sdk.com/docs/controltower_list_landing_zones/) for full documentation.
#'
#' @param maxResults The maximum number of returned landing zone ARNs, which is one.
#' @param nextToken The token to continue the list from a previous API call with the same
#' parameters.
#'
#' @keywords internal
#'
#' @rdname controltower_list_landing_zones
controltower_list_landing_zones <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListLandingZones",
    http_method = "POST",
    http_path = "/list-landingzones",
    host_prefix = "",
    paginator = list(input_token = "nextToken", output_token = "nextToken", limit_key = "maxResults", result_key = "landingZones"),
    stream_api = FALSE
  )
  input <- .controltower$list_landing_zones_input(maxResults = maxResults, nextToken = nextToken)
  output <- .controltower$list_landing_zones_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_landing_zones <- controltower_list_landing_zones

#' Returns a list of tags associated with the resource
#'
#' @description
#' Returns a list of tags associated with the resource. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_list_tags_for_resource/](https://www.paws-r-sdk.com/docs/controltower_list_tags_for_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The ARN of the resource.
#'
#' @keywords internal
#'
#' @rdname controltower_list_tags_for_resource
controltower_list_tags_for_resource <- function(resourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "GET",
    http_path = "/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$list_tags_for_resource_input(resourceArn = resourceArn)
  output <- .controltower$list_tags_for_resource_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$list_tags_for_resource <- controltower_list_tags_for_resource

#' Re-enables an EnabledBaseline resource
#'
#' @description
#' Re-enables an `EnabledBaseline` resource. For example, this API can re-apply the existing `Baseline` after a new member account is moved to the target OU. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_reset_enabled_baseline/](https://www.paws-r-sdk.com/docs/controltower_reset_enabled_baseline/) for full documentation.
#'
#' @param enabledBaselineIdentifier &#91;required&#93; Specifies the ID of the `EnabledBaseline` resource to be re-enabled, in
#' ARN format.
#'
#' @keywords internal
#'
#' @rdname controltower_reset_enabled_baseline
controltower_reset_enabled_baseline <- function(enabledBaselineIdentifier) {
  op <- new_operation(
    name = "ResetEnabledBaseline",
    http_method = "POST",
    http_path = "/reset-enabled-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$reset_enabled_baseline_input(enabledBaselineIdentifier = enabledBaselineIdentifier)
  output <- .controltower$reset_enabled_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$reset_enabled_baseline <- controltower_reset_enabled_baseline

#' Resets an enabled control
#'
#' @description
#' Resets an enabled control.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_reset_enabled_control/](https://www.paws-r-sdk.com/docs/controltower_reset_enabled_control/) for full documentation.
#'
#' @param enabledControlIdentifier &#91;required&#93; The ARN of the enabled control to be reset.
#'
#' @keywords internal
#'
#' @rdname controltower_reset_enabled_control
controltower_reset_enabled_control <- function(enabledControlIdentifier) {
  op <- new_operation(
    name = "ResetEnabledControl",
    http_method = "POST",
    http_path = "/reset-enabled-control",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$reset_enabled_control_input(enabledControlIdentifier = enabledControlIdentifier)
  output <- .controltower$reset_enabled_control_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$reset_enabled_control <- controltower_reset_enabled_control

#' This API call resets a landing zone
#'
#' @description
#' This API call resets a landing zone. It starts an asynchronous operation that resets the landing zone to the parameters specified in the original configuration, which you specified in the manifest file. Nothing in the manifest file's original landing zone configuration is changed during the reset process, by default. This API is not the same as a rollback of a landing zone version, which is not a supported operation.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_reset_landing_zone/](https://www.paws-r-sdk.com/docs/controltower_reset_landing_zone/) for full documentation.
#'
#' @param landingZoneIdentifier &#91;required&#93; The unique identifier of the landing zone.
#'
#' @keywords internal
#'
#' @rdname controltower_reset_landing_zone
controltower_reset_landing_zone <- function(landingZoneIdentifier) {
  op <- new_operation(
    name = "ResetLandingZone",
    http_method = "POST",
    http_path = "/reset-landingzone",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$reset_landing_zone_input(landingZoneIdentifier = landingZoneIdentifier)
  output <- .controltower$reset_landing_zone_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$reset_landing_zone <- controltower_reset_landing_zone

#' Applies tags to a resource
#'
#' @description
#' Applies tags to a resource. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_tag_resource/](https://www.paws-r-sdk.com/docs/controltower_tag_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The ARN of the resource to be tagged.
#' @param tags &#91;required&#93; Tags to be applied to the resource.
#'
#' @keywords internal
#'
#' @rdname controltower_tag_resource
controltower_tag_resource <- function(resourceArn, tags) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$tag_resource_input(resourceArn = resourceArn, tags = tags)
  output <- .controltower$tag_resource_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$tag_resource <- controltower_tag_resource

#' Removes tags from a resource
#'
#' @description
#' Removes tags from a resource. For usage examples, see the [*Controls Reference Guide*](https://docs.aws.amazon.com/controltower/latest/controlreference/control-api-examples-short.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_untag_resource/](https://www.paws-r-sdk.com/docs/controltower_untag_resource/) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The ARN of the resource.
#' @param tagKeys &#91;required&#93; Tag keys to be removed from the resource.
#'
#' @keywords internal
#'
#' @rdname controltower_untag_resource
controltower_untag_resource <- function(resourceArn, tagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "DELETE",
    http_path = "/tags/{resourceArn}",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$untag_resource_input(resourceArn = resourceArn, tagKeys = tagKeys)
  output <- .controltower$untag_resource_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$untag_resource <- controltower_untag_resource

#' Updates an EnabledBaseline resource's applied parameters or version
#'
#' @description
#' Updates an `EnabledBaseline` resource's applied parameters or version. For usage examples, see [*the Amazon Web Services Control Tower User Guide*](https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html) .
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_update_enabled_baseline/](https://www.paws-r-sdk.com/docs/controltower_update_enabled_baseline/) for full documentation.
#'
#' @param baselineVersion &#91;required&#93; Specifies the new `Baseline` version, to which the `EnabledBaseline`
#' should be updated.
#' @param enabledBaselineIdentifier &#91;required&#93; Specifies the `EnabledBaseline` resource to be updated.
#' @param parameters Parameters to apply when making an update.
#'
#' @keywords internal
#'
#' @rdname controltower_update_enabled_baseline
controltower_update_enabled_baseline <- function(baselineVersion, enabledBaselineIdentifier, parameters = NULL) {
  op <- new_operation(
    name = "UpdateEnabledBaseline",
    http_method = "POST",
    http_path = "/update-enabled-baseline",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$update_enabled_baseline_input(baselineVersion = baselineVersion, enabledBaselineIdentifier = enabledBaselineIdentifier, parameters = parameters)
  output <- .controltower$update_enabled_baseline_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$update_enabled_baseline <- controltower_update_enabled_baseline

#' Updates the configuration of an already enabled control
#'
#' @description
#' Updates the configuration of an already enabled control.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_update_enabled_control/](https://www.paws-r-sdk.com/docs/controltower_update_enabled_control/) for full documentation.
#'
#' @param enabledControlIdentifier &#91;required&#93; The ARN of the enabled control that will be updated.
#' @param parameters &#91;required&#93; A key/value pair, where `Key` is of type `String` and `Value` is of type
#' `Document`.
#'
#' @keywords internal
#'
#' @rdname controltower_update_enabled_control
controltower_update_enabled_control <- function(enabledControlIdentifier, parameters) {
  op <- new_operation(
    name = "UpdateEnabledControl",
    http_method = "POST",
    http_path = "/update-enabled-control",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$update_enabled_control_input(enabledControlIdentifier = enabledControlIdentifier, parameters = parameters)
  output <- .controltower$update_enabled_control_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$update_enabled_control <- controltower_update_enabled_control

#' This API call updates the landing zone
#'
#' @description
#' This API call updates the landing zone. It starts an asynchronous operation that updates the landing zone based on the new landing zone version, or on the changed parameters specified in the updated manifest file.
#'
#' See [https://www.paws-r-sdk.com/docs/controltower_update_landing_zone/](https://www.paws-r-sdk.com/docs/controltower_update_landing_zone/) for full documentation.
#'
#' @param landingZoneIdentifier &#91;required&#93; The unique identifier of the landing zone.
#' @param manifest &#91;required&#93; The manifest file (JSON) is a text file that describes your Amazon Web
#' Services resources. For an example, review [Launch your landing
#' zone](https://docs.aws.amazon.com/controltower/latest/userguide/lz-api-launch.html).
#' The example manifest file contains each of the available parameters. The
#' schema for the landing zone's JSON manifest file is not published, by
#' design.
#' @param version &#91;required&#93; The landing zone version, for example, 3.2.
#'
#' @keywords internal
#'
#' @rdname controltower_update_landing_zone
controltower_update_landing_zone <- function(landingZoneIdentifier, manifest, version) {
  op <- new_operation(
    name = "UpdateLandingZone",
    http_method = "POST",
    http_path = "/update-landingzone",
    host_prefix = "",
    paginator = list(),
    stream_api = FALSE
  )
  input <- .controltower$update_landing_zone_input(landingZoneIdentifier = landingZoneIdentifier, manifest = manifest, version = version)
  output <- .controltower$update_landing_zone_output()
  config <- get_config()
  svc <- .controltower$service(config, op)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.controltower$operations$update_landing_zone <- controltower_update_landing_zone
