# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common new_handlers new_service set_config merge_config
NULL

#' AWS Systems Manager Incident Manager
#'
#' @description
#' Systems Manager Incident Manager is an incident management console
#' designed to help users mitigate and recover from incidents affecting
#' their Amazon Web Services-hosted applications. An incident is any
#' unplanned interruption or reduction in quality of services.
#' 
#' Incident Manager increases incident resolution by notifying responders
#' of impact, highlighting relevant troubleshooting data, and providing
#' collaboration tools to get services back up and running. To achieve the
#' primary goal of reducing the time-to-resolution of critical incidents,
#' Incident Manager automates response plans and enables responder team
#' escalation.
#'
#' @param
#' config
#' Optional configuration of credentials, endpoint, and/or region.
#' \itemize{
#' \item{\strong{credentials}: \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }}
#' \item{\strong{endpoint}: The complete URL to use for the constructed client.}
#' \item{\strong{region}: The AWS Region used in instantiating the client.}
#' \item{\strong{close_connection}: Immediately close all HTTP connections.}
#' \item{\strong{timeout}: The time in seconds till a timeout exception is thrown when attempting to make a connection. The default is 60 seconds.}
#' \item{\strong{s3_force_path_style}: Set this to `true` to force the request to use path-style addressing, i.e. `http://s3.amazonaws.com/BUCKET/KEY`.}
#' \item{\strong{sts_regional_endpoint}: Set sts regional endpoint resolver to regional or legacy \url{https://docs.aws.amazon.com/sdkref/latest/guide/feature-sts-regionalized-endpoints.html}}
#' }
#' @param
#' credentials
#' Optional credentials shorthand for the config parameter
#' \itemize{
#' \item{\strong{creds}: \itemize{
#' \item{\strong{access_key_id}: AWS access key ID}
#' \item{\strong{secret_access_key}: AWS secret access key}
#' \item{\strong{session_token}: AWS temporary session token}
#' }}
#' \item{\strong{profile}: The name of a profile to use. If not given, then the default profile is used.}
#' \item{\strong{anonymous}: Set anonymous credentials.}
#' }
#' @param
#' endpoint
#' Optional shorthand for complete URL to use for the constructed client.
#' @param
#' region
#' Optional shorthand for AWS Region used in instantiating the client.
#'
#' @section Service syntax:
#' ```
#' svc <- ssmincidents(
#'   config = list(
#'     credentials = list(
#'       creds = list(
#'         access_key_id = "string",
#'         secret_access_key = "string",
#'         session_token = "string"
#'       ),
#'       profile = "string",
#'       anonymous = "logical"
#'     ),
#'     endpoint = "string",
#'     region = "string",
#'     close_connection = "logical",
#'     timeout = "numeric",
#'     s3_force_path_style = "logical",
#'     sts_regional_endpoint = "string"
#'   ),
#'   credentials = list(
#'     creds = list(
#'       access_key_id = "string",
#'       secret_access_key = "string",
#'       session_token = "string"
#'     ),
#'     profile = "string",
#'     anonymous = "logical"
#'   ),
#'   endpoint = "string",
#'   region = "string"
#' )
#' ```
#'
#' @examples
#' \dontrun{
#' svc <- ssmincidents()
#' svc$batch_get_incident_findings(
#'   Foo = 123
#' )
#' }
#'
#' @section Operations:
#' \tabular{ll}{
#'  \link[=ssmincidents_batch_get_incident_findings]{batch_get_incident_findings} \tab Retrieves details about all specified findings for an incident, including descriptive details about each finding\cr
#'  \link[=ssmincidents_create_replication_set]{create_replication_set} \tab A replication set replicates and encrypts your data to the provided Regions with the provided KMS key\cr
#'  \link[=ssmincidents_create_response_plan]{create_response_plan} \tab Creates a response plan that automates the initial response to incidents\cr
#'  \link[=ssmincidents_create_timeline_event]{create_timeline_event} \tab Creates a custom timeline event on the incident details page of an incident record\cr
#'  \link[=ssmincidents_delete_incident_record]{delete_incident_record} \tab Delete an incident record from Incident Manager\cr
#'  \link[=ssmincidents_delete_replication_set]{delete_replication_set} \tab Deletes all Regions in your replication set\cr
#'  \link[=ssmincidents_delete_resource_policy]{delete_resource_policy} \tab Deletes the resource policy that Resource Access Manager uses to share your Incident Manager resource\cr
#'  \link[=ssmincidents_delete_response_plan]{delete_response_plan} \tab Deletes the specified response plan\cr
#'  \link[=ssmincidents_delete_timeline_event]{delete_timeline_event} \tab Deletes a timeline event from an incident\cr
#'  \link[=ssmincidents_get_incident_record]{get_incident_record} \tab Returns the details for the specified incident record\cr
#'  \link[=ssmincidents_get_replication_set]{get_replication_set} \tab Retrieve your Incident Manager replication set\cr
#'  \link[=ssmincidents_get_resource_policies]{get_resource_policies} \tab Retrieves the resource policies attached to the specified response plan\cr
#'  \link[=ssmincidents_get_response_plan]{get_response_plan} \tab Retrieves the details of the specified response plan\cr
#'  \link[=ssmincidents_get_timeline_event]{get_timeline_event} \tab Retrieves a timeline event based on its ID and incident record\cr
#'  \link[=ssmincidents_list_incident_findings]{list_incident_findings} \tab Retrieves a list of the IDs of findings, plus their last modified times, that have been identified for a specified incident\cr
#'  \link[=ssmincidents_list_incident_records]{list_incident_records} \tab Lists all incident records in your account\cr
#'  \link[=ssmincidents_list_related_items]{list_related_items} \tab List all related items for an incident record\cr
#'  \link[=ssmincidents_list_replication_sets]{list_replication_sets} \tab Lists details about the replication set configured in your account\cr
#'  \link[=ssmincidents_list_response_plans]{list_response_plans} \tab Lists all response plans in your account\cr
#'  \link[=ssmincidents_list_tags_for_resource]{list_tags_for_resource} \tab Lists the tags that are attached to the specified response plan or incident\cr
#'  \link[=ssmincidents_list_timeline_events]{list_timeline_events} \tab Lists timeline events for the specified incident record\cr
#'  \link[=ssmincidents_put_resource_policy]{put_resource_policy} \tab Adds a resource policy to the specified response plan\cr
#'  \link[=ssmincidents_start_incident]{start_incident} \tab Used to start an incident from CloudWatch alarms, EventBridge events, or manually\cr
#'  \link[=ssmincidents_tag_resource]{tag_resource} \tab Adds a tag to a response plan\cr
#'  \link[=ssmincidents_untag_resource]{untag_resource} \tab Removes a tag from a resource\cr
#'  \link[=ssmincidents_update_deletion_protection]{update_deletion_protection} \tab Update deletion protection to either allow or deny deletion of the final Region in a replication set\cr
#'  \link[=ssmincidents_update_incident_record]{update_incident_record} \tab Update the details of an incident record\cr
#'  \link[=ssmincidents_update_related_items]{update_related_items} \tab Add or remove related items from the related items tab of an incident record\cr
#'  \link[=ssmincidents_update_replication_set]{update_replication_set} \tab Add or delete Regions from your replication set\cr
#'  \link[=ssmincidents_update_response_plan]{update_response_plan} \tab Updates the specified response plan\cr
#'  \link[=ssmincidents_update_timeline_event]{update_timeline_event} \tab Updates a timeline event
#' }
#'
#' @return
#' A client for the service. You can call the service's operations using
#' syntax like `svc$operation(...)`, where `svc` is the name you've assigned
#' to the client. The available operations are listed in the
#' Operations section.
#'
#' @rdname ssmincidents
#' @export
ssmincidents <- function(config = list(), credentials = list(), endpoint = NULL, region = NULL) {
  config <- merge_config(
    config,
    list(
      credentials = credentials,
      endpoint = endpoint,
      region = region
    )
  )
  svc <- .ssmincidents$operations
  svc <- set_config(svc, config)
  return(svc)
}

# Private API objects: metadata, handlers, interfaces, etc.
.ssmincidents <- list()

.ssmincidents$operations <- list()

.ssmincidents$metadata <- list(
  service_name = "ssmincidents",
  endpoints = list("^(us|eu|ap|sa|ca|me|af|il|mx)\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.amazonaws.com", global = FALSE), "^cn\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.amazonaws.com.cn", global = FALSE), "^us\\-gov\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.amazonaws.com", global = FALSE), "^us\\-iso\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.c2s.ic.gov", global = FALSE), "^us\\-isob\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.sc2s.sgov.gov", global = FALSE), "^eu\\-isoe\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.cloud.adc-e.uk", global = FALSE), "^us\\-isof\\-\\w+\\-\\d+$" = list(endpoint = "ssm-incidents.{region}.csp.hci.ic.gov", global = FALSE)),
  service_id = "SSM Incidents",
  api_version = "2018-05-10",
  signing_name = "ssm-incidents",
  json_version = "1.1",
  target_prefix = ""
)

.ssmincidents$service <- function(config = list(), op = NULL) {
  handlers <- new_handlers("restjson", "v4")
  new_service(.ssmincidents$metadata, handlers, config, op)
}
